/// <reference types="node" />
import { PermissionString, Snowflake } from 'discord.js';
import { SilentClient } from '../client/SilentClient';
import Timer = NodeJS.Timer;
export declare abstract class Command<S extends SilentClient = SilentClient> {
    restricted: Array<{
        type: 'role' | 'user';
        id: Snowflake;
    }>;
    guildOnly: boolean;
    ownerOnly: boolean;
    desc: string;
    name: string;
    usage: string;
    nsfw: boolean;
    aliases: string[];
    hidden: boolean;
    dmOnly: boolean;
    userPermissions: PermissionString[];
    clientPermissions: PermissionString[];
    example: string;
    rateLimit: {
        times: number;
        interval: number;
    };
    _rateLimits: Map<Snowflake, {
        start: number;
        uses: number;
        timeout: Timer;
    }>;
    minRole: string | Snowflake;
    _className: string;
    protected _client: S;
    private initiated;
    protected constructor();
    /**
     * Initiate a new Command
     * @param client
     * @private
     */
    _init(client: S): void;
    /**
     * @private
     */
    throttle(userID: Snowflake): {
        start: number;
        uses: number;
        timeout: Timer;
    };
    /**
     * Run the command
     */
    abstract run(...values: any[]): any;
}
