"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Command {
    constructor() {
        this._rateLimits = new Map();
        this.initiated = false;
    }
    /**
     * Initiate a new Command
     * @param client
     * @private
     */
    _init(client) {
        this._client = client;
        if (!this.desc)
            this.desc = 'Default description.';
        if (!this.name)
            throw new Error('Command name has to be specified.');
        if (!this.usage)
            this.usage = `<prefix>${this.name}`;
        if (!this.hidden === undefined)
            this.hidden = false;
        if (!this.aliases)
            this.aliases = [];
        if (!this.userPermissions)
            this.userPermissions = [];
        if (!this.clientPermissions)
            this.clientPermissions = [];
        if (!this.restricted)
            this.restricted = [];
        if (!this.dmOnly)
            this.dmOnly = false;
        if (!this.example)
            this.example = 'Default example.';
        this.initiated = true;
    }
    /**
     * @private
     */
    throttle(userID) {
        if (!this.rateLimit)
            return null;
        let obj = this._rateLimits.get(userID);
        if (!obj) {
            obj = {
                uses: 0,
                start: Date.now(),
                timeout: this._client.setTimeout(() => {
                    this._rateLimits.delete(userID);
                }, this.rateLimit.interval * 1000)
            };
            this._rateLimits.set(userID, obj);
        }
        return obj;
    }
}
exports.Command = Command;
//# sourceMappingURL=Command.js.map