"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const glob = require("glob");
const path = require("path");
class CommandLoader {
    constructor(client) {
        this.client = client;
        this._commands = client.commands;
    }
    loadFromPath(pathUser, base) {
        const resolvedPath = path.resolve(base ? `${__dirname}/base` : `${this.client.baseDir || ''}${pathUser}`);
        const commandFiles = glob.sync(`${resolvedPath}/**/*.js`);
        const loadedCommands = [];
        for (const file of commandFiles) {
            delete require.cache[require.resolve(file)];
            const loadedFile = require(file);
            const name = this._findCommandClass(loadedFile).name;
            const commandClass = this._findCommandClass(loadedFile);
            if (!commandClass)
                continue;
            const commandInstance = new commandClass();
            Object.defineProperty(commandInstance, '_className', {
                value: name,
                configurable: true,
                writable: true,
                enumerable: true
            });
            loadedCommands.push(commandInstance);
        }
        for (const command of loadedCommands) {
            this._commands._registerInternal(command);
        }
        return loadedCommands.length;
    }
    _findCommandClass(obj) {
        let foundClass;
        const keys = Object.keys(obj);
        if (Object.getPrototypeOf(obj).name === 'Command') {
            foundClass = obj;
        }
        else if (keys.length > 0) {
            for (const key of keys) {
                foundClass = this._findCommandClass(obj[key]);
                if (!foundClass)
                    continue;
                if (Object.getPrototypeOf(foundClass).name === 'Command')
                    break;
            }
        }
        return foundClass;
    }
}
exports.CommandLoader = CommandLoader;
//# sourceMappingURL=CommandLoader.js.map