"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const glob = require("glob");
const path = require("path");
class EventLoader {
    constructor(client) {
        this.client = client;
        this._events = client.events;
    }
    loadFromPath(pathUser) {
        const resolvedPath = path.resolve(`${this.client.baseDir || ''}${pathUser}`);
        const eventFiles = glob.sync(`${resolvedPath}/**/*.js`);
        const loadedEvents = [];
        for (const file of eventFiles) {
            delete require.cache[require.resolve(file)];
            const loadedFile = require(file);
            const eventClass = this._findCommandClass(loadedFile);
            if (!eventClass)
                continue;
            const eventInstance = new eventClass();
            loadedEvents.push(eventInstance);
        }
        for (const event of loadedEvents) {
            this._events._registerInternal(event);
        }
        return loadedEvents.length;
    }
    _findCommandClass(obj) {
        let foundClass;
        const keys = Object.keys(obj);
        if (Object.getPrototypeOf(obj).name === 'Event') {
            foundClass = obj;
        }
        else if (keys.length > 0) {
            for (const key of keys) {
                foundClass = this._findCommandClass(obj[key]);
                if (!foundClass)
                    continue;
                if (Object.getPrototypeOf(foundClass).name === 'Event')
                    break;
            }
        }
        return foundClass;
    }
}
exports.EventLoader = EventLoader;
//# sourceMappingURL=EventLoader.js.map